package org.ets.ibt.external.services.ibis;

import java.io.Serializable;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import org.ets.ibt.delivery.server.config.ConfigParamCache;
import org.ets.ibt.delivery.server.utility.ServerProperties;
import org.ets.ibt.external.clients.ibis.CompositeAdminDataServiceBindingStub;
import org.ets.ibt.external.clients.ibis.CompositeAdminDataServiceServiceLocator;
import org.ets.ibt2.common.enums.OAuthEnums;
import org.ets.ibt2.common.util.oauth.OauthServiceUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class CompositeAdminDataServiceReposter implements Serializable {

   private static final Logger Log = LoggerFactory.getLogger(CompositeAdminDataServiceReposter.class);
   private static final long serialVersionUID = 8544312641156435647L;


   public static void postAdminService(String programCode, String testCode, String adminCode, String adminName, Calendar startDate, Calendar endDate, String status, org.ets.ibt.external.clients.ibis.CompositePackages compositePackages) throws Exception {
      List urlInfoList = ServerProperties.getWebServiceReposterURLInfo();
      if(urlInfoList.isEmpty()) {
         Log.info("postAdminService(): repost URL is empty! No admin data is reposted");
      } else {
         boolean repostOAuthFlag = ServerProperties.isProducerOAuthRepostFlag();
         Log.info("postAdminService(): starting to repost admin data. Destination size = {}, repostOAuthFlag = {}", Integer.valueOf(urlInfoList.size()), Boolean.valueOf(repostOAuthFlag));
         Iterator var10 = urlInfoList.iterator();

         while(var10.hasNext()) {
            List urlInfo = (List)var10.next();
            String url = (String)urlInfo.get(0);
            String token;
            if(!repostOAuthFlag) {
               token = (String)urlInfo.get(1);
               String pwd = (String)urlInfo.get(2);
               postAdminService(programCode, testCode, adminCode, adminName, startDate, endDate, status, compositePackages, url, token, pwd);
            } else {
               Log.info("CompositeDataService: Generating IDAAS TOKEN");
               OAuthEnums.BEARER.getValue();
               token = OauthServiceUtils.getInstance().getCachedOAuthTokenByUrl(OAuthEnums.UNIFY_INTERNAL_REPOST_OAUTH_CACHE.getValue(), ServerProperties.getOauthTokenURL(), ConfigParamCache.getInstance().getAwsSecretsManagerParamValue(OAuthEnums.UNIFY_INTERNAL_CLIENT_ID.getValue()), ConfigParamCache.getInstance().getAwsSecretsManagerParamValue(OAuthEnums.UNIFY_INTERNAL_CLIENT_SECRET.getValue()), (String)urlInfo.get(3));
               postAdminService(programCode, testCode, adminCode, adminName, startDate, endDate, status, compositePackages, url, token);
            }
         }

      }
   }

   public static void postAdminService(String programCode, String testCode, String adminCode, String adminName, Calendar startDate, Calendar endDate, String status, org.ets.ibt.external.clients.ibis.CompositePackages compositePackages, String url, String userId, String pwd) throws Exception {
      new Thread;
      status.<init>(compositePackages);
      endDate.start();
   }

   public static void postAdminService(String programCode, String testCode, String adminCode, String adminName, Calendar startDate, Calendar endDate, String status, org.ets.ibt.external.clients.ibis.CompositePackages compositePackages, String url, String oAuthToken) throws Exception {
      new Thread;
      status.<init>(compositePackages);
      endDate.start();
   }

   public static String generateAdminData(String programCode, String testCode, String adminCode, String adminName, Calendar startDate, Calendar endDate, org.ets.ibt.external.clients.ibis.CompositePackages compositePackages) {
      SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm");
      StringBuffer bf = new StringBuffer("ADMIN\n");
      bf.append("Program Code:").append(programCode).append("\n");
      bf.append("Test Code:").append(testCode).append("\n");
      bf.append("Admin Code:").append(adminCode).append("\n");
      bf.append("Admin Name:").append(adminName).append("\n");
      bf.append("Start Date:").append(dateFormat.format(startDate.getTime())).append("\n");
      bf.append("End Date:").append(dateFormat.format(endDate.getTime())).append("\n");
      org.ets.ibt.external.clients.ibis.CompositeEntry[] var9 = compositePackages.getCompositeEntry();
      int var10 = var9.length;

      for(int var11 = 0; var11 < var10; ++var11) {
         org.ets.ibt.external.clients.ibis.CompositeEntry entry = var9[var11];
         bf.append("Delivery Package ID:\n");
         bf.append("Content ID:").append(entry.getDeliveryPackageID()).append("\n");
         bf.append("Status:").append(entry.getPackageStatus()).append("\n");
         org.ets.ibt.external.clients.ibis.CompositeSubFormData[] var13 = entry.getCompositeSubFormData();
         int var14 = var13.length;

         for(int var15 = 0; var15 < var14; ++var15) {
            org.ets.ibt.external.clients.ibis.CompositeSubFormData form = var13[var15];
            bf.append("Form Data:").append(form.getSubFormCode());
            org.ets.ibt.external.clients.ibis.CompositeWeightData[] var17 = form.getCompositeWeightData();
            int var18 = var17.length;

            for(int var19 = 0; var19 < var18; ++var19) {
               org.ets.ibt.external.clients.ibis.CompositeWeightData w = var17[var19];
               bf.append(",").append(w.getDeliveryGroupName()).append(",").append(w.getDeliveryGroupWeight());
            }

            bf.append("\n");
         }
      }

      return bf.toString();
   }

   public static void main(String[] args) throws Exception {
      String programCode = "PRI";
      String testCode = "174";
      String adminName = "Test";
      String adminCode = "20170703A";
      SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm");
      Calendar startDate = Calendar.getInstance();
      startDate.setTime(dateFormat.parse("2020-04-26 20:00"));
      Calendar endDate = Calendar.getInstance();
      endDate.setTime(dateFormat.parse("2020-05-31 19:59"));
      String status = "Finalized";
      org.ets.ibt.external.clients.ibis.CompositeEntry[] compositeEntry = new org.ets.ibt.external.clients.ibis.CompositeEntry[]{new org.ets.ibt.external.clients.ibis.CompositeEntry()};
      compositeEntry[0].setDeliveryPackageID("PRI174STP00001000PKG001");
      compositeEntry[0].setPackageName("PRI174STP00001000PKG001");
      compositeEntry[0].setPackageStatus("Certified");
      org.ets.ibt.external.clients.ibis.CompositeSubFormData[] forms = new org.ets.ibt.external.clients.ibis.CompositeSubFormData[]{new org.ets.ibt.external.clients.ibis.CompositeSubFormData(), null};
      forms[0].setSubFormCode("000107-01-0000000001");
      org.ets.ibt.external.clients.ibis.CompositeWeightData[] weights1 = new org.ets.ibt.external.clients.ibis.CompositeWeightData[]{new org.ets.ibt.external.clients.ibis.CompositeWeightData()};
      weights1[0].setDeliveryGroupName("001");
      weights1[0].setDeliveryGroupWeight("0.5");
      forms[0].setCompositeWeightData(weights1);
      forms[1] = new org.ets.ibt.external.clients.ibis.CompositeSubFormData();
      forms[1].setSubFormCode("000107-02-0000000001");
      org.ets.ibt.external.clients.ibis.CompositeWeightData[] weights2 = new org.ets.ibt.external.clients.ibis.CompositeWeightData[]{new org.ets.ibt.external.clients.ibis.CompositeWeightData()};
      weights2[0].setDeliveryGroupName("002");
      weights2[0].setDeliveryGroupWeight("1");
      forms[1].setCompositeWeightData(weights2);
      compositeEntry[0].setCompositeSubFormData(forms);
      org.ets.ibt.external.clients.ibis.CompositePackages packages = new org.ets.ibt.external.clients.ibis.CompositePackages();
      packages.setCompositeEntry(compositeEntry);
      String url = "http://localhost:8001/internal/services/CompositeAdminDataService";
      OAuthEnums.BEARER.getValue();
      String oAuthToken = OauthServiceUtils.getInstance().getCachedOAuthTokenByUrl(OAuthEnums.UNIFY_INTERNAL_OAUTH_CACHE.getValue(), ServerProperties.getOauthTokenURL(), ConfigParamCache.getInstance().getAwsSecretsManagerParamValue(OAuthEnums.UNIFY_INTERNAL_CLIENT_ID.getValue()), ConfigParamCache.getInstance().getAwsSecretsManagerParamValue(OAuthEnums.UNIFY_INTERNAL_CLIENT_SECRET.getValue()), "https://ibtsb.ets.org/");
      postAdminService(programCode, testCode, adminCode, adminName, startDate, endDate, status, packages, url, oAuthToken);
   }

   // $FF: synthetic method
   private static void lambda$postAdminService$1(String programCode, String testCode, String adminCode, String url, String oAuthToken, String adminName, Calendar startDate, Calendar endDate, String status, org.ets.ibt.external.clients.ibis.CompositePackages compositePackages) {
      Log.info("postAdminService(): posting admin data [{}{}/{}] to {}", new Object[]{programCode, testCode, adminCode, url});

      try {
         CompositeAdminDataServiceServiceLocator e = new CompositeAdminDataServiceServiceLocator();
         e.setCompositeAdminDataServicePortEndpointAddress(url);
         org.ets.ibt.external.clients.ibis.CompositeAdminDataService service = e.getCompositeAdminDataServicePort(new URL(url));
         CompositeAdminDataServiceBindingStub stub = (CompositeAdminDataServiceBindingStub)e.getPort(service.getClass());
         Hashtable headers = new Hashtable();
         headers.put("Authorization", oAuthToken);
         stub._setProperty("HTTP-Request-Headers", headers);
         org.ets.ibt.external.clients.ibis.CompositeIBTResponse response = stub.submitAdminData(programCode, testCode, adminName, adminCode, startDate, endDate, status, compositePackages);
         if(response != null) {
            org.ets.ibt.external.clients.ibis.CompositeResponseCode responseCode = response.getCompositeResponseCode();
            Log.info("postAdminService(): response = {}, desc = {}", responseCode.getValue(), response.getDescription());
            String var16 = responseCode.getValue();
            byte var17 = -1;
            switch(var16.hashCode()) {
            case -2139259228:
               if(var16.equals("_Success")) {
                  var17 = 0;
               }
               break;
            case -1592942296:
               if(var16.equals("_DataValidationFailure")) {
                  var17 = 4;
               }
               break;
            case 53071345:
               if(var16.equals("_InvalidParameter")) {
                  var17 = 2;
               }
               break;
            case 263178918:
               if(var16.equals("_ServerError")) {
                  var17 = 1;
               }
               break;
            case 848075550:
               if(var16.equals("_ClientError")) {
                  var17 = 5;
               }
               break;
            case 1716741996:
               if(var16.equals("_Duplicate")) {
                  var17 = 3;
               }
            }

            switch(var17) {
            case 0:
            default:
               break;
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
               org.ets.ibt.external.clients.ibis.CompositeErrorInfo errorInfo = response.getCompositeErrorInfo();
               if(errorInfo != null) {
                  Log.info("postAdminService(): error = {}, desc = {}", errorInfo.getCompositeErrorCode().getValue(), errorInfo.getDetailErrorMessage());
               }

               Log.info("Admin Post Data:\n{}", generateAdminData(programCode, testCode, adminCode, adminName, startDate, endDate, compositePackages));
            }
         }
      } catch (Throwable var22) {
         Log.error("postAdminService()", var22);
      } finally {
         Log.info("postAdminService(): posting admin data posting is completed");
      }

   }

   // $FF: synthetic method
   private static void lambda$postAdminService$0(String programCode, String testCode, String adminCode, String url, String userId, String pwd, String adminName, Calendar startDate, Calendar endDate, String status, org.ets.ibt.external.clients.ibis.CompositePackages compositePackages) {
      Log.info("postAdminService(): posting admin data [{}{}/{}] to {}", new Object[]{programCode, testCode, adminCode, url});

      try {
         CompositeAdminDataServiceServiceLocator e = new CompositeAdminDataServiceServiceLocator();
         e.setCompositeAdminDataServicePortEndpointAddress(url);
         org.ets.ibt.external.clients.ibis.CompositeAdminDataService service = e.getCompositeAdminDataServicePort(new URL(url));
         CompositeAdminDataServiceBindingStub stub = (CompositeAdminDataServiceBindingStub)e.getPort(service.getClass());
         stub.setUsername(userId);
         stub.setPassword(pwd);
         org.ets.ibt.external.clients.ibis.CompositeIBTResponse response = stub.submitAdminData(programCode, testCode, adminName, adminCode, startDate, endDate, status, compositePackages);
         if(response != null) {
            org.ets.ibt.external.clients.ibis.CompositeResponseCode responseCode = response.getCompositeResponseCode();
            Log.info("postAdminService(): response = {}, desc = {}", responseCode.getValue(), response.getDescription());
            String var16 = responseCode.getValue();
            byte var17 = -1;
            switch(var16.hashCode()) {
            case -2139259228:
               if(var16.equals("_Success")) {
                  var17 = 0;
               }
               break;
            case -1592942296:
               if(var16.equals("_DataValidationFailure")) {
                  var17 = 4;
               }
               break;
            case 53071345:
               if(var16.equals("_InvalidParameter")) {
                  var17 = 2;
               }
               break;
            case 263178918:
               if(var16.equals("_ServerError")) {
                  var17 = 1;
               }
               break;
            case 848075550:
               if(var16.equals("_ClientError")) {
                  var17 = 5;
               }
               break;
            case 1716741996:
               if(var16.equals("_Duplicate")) {
                  var17 = 3;
               }
            }

            switch(var17) {
            case 0:
            default:
               break;
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
               org.ets.ibt.external.clients.ibis.CompositeErrorInfo errorInfo = response.getCompositeErrorInfo();
               if(errorInfo != null) {
                  Log.info("postAdminService(): error = {}, desc = {}", errorInfo.getCompositeErrorCode().getValue(), errorInfo.getDetailErrorMessage());
               }

               Log.info("Admin Post Data:\n{}", generateAdminData(programCode, testCode, adminCode, adminName, startDate, endDate, compositePackages));
            }
         }
      } catch (Throwable var22) {
         Log.error("postAdminService()", var22);
      } finally {
         Log.info("postAdminService(): posting admin data posting is completed");
      }

   }

}
